==> haskell-persistent-qq-2.12.0.7-62-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-qq
version:              2.12.0.7
visibility:           public
id:                   persistent-qq-2.12.0.7-IqAOrTPetTr5g9VfZFbfLS
key:                  persistent-qq-2.12.0.7-IqAOrTPetTr5g9VfZFbfLS
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
homepage:             https://github.com/yesodweb/persistent#readme
synopsis:             Provides a quasi-quoter for raw SQL for persistent
description:
    Please see README and API docs at <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  81dc9a0847a48dc4946348c2278aff06
exposed:              True
exposed-modules:      Database.Persist.Sql.Raw.QQ
hidden-modules:       Paths_persistent_qq
import-dirs:          /usr/lib/ghc-9.6.6/site-local/persistent-qq-2.12.0.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/persistent-qq-2.12.0.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/persistent-qq-2.12.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-qq
hs-libraries:         HSpersistent-qq-2.12.0.7-IqAOrTPetTr5g9VfZFbfLS
depends:
    base-4.18.2.1 haskell-src-meta-0.8.15-GqSWx9monJhDwN3u4roT6d
    mtl-2.3.1 persistent-2.14.5.2-GJyCnJ8J8PvBVRSOBxUsv4
    template-haskell-2.20.0.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-persistent-qq/html/persistent-qq.haddock

haddock-html:         /usr/share/doc/haskell-persistent-qq/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-qq-2.12.0.7-63-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-qq
version:              2.12.0.7
visibility:           public
id:                   persistent-qq-2.12.0.7-Bh5xC0O2VSz1FVQ3mqafvh
key:                  persistent-qq-2.12.0.7-Bh5xC0O2VSz1FVQ3mqafvh
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
homepage:             https://github.com/yesodweb/persistent#readme
synopsis:             Provides a quasi-quoter for raw SQL for persistent
description:
    Please see README and API docs at <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  1cf51d253037c546d1a4c76313623a9d
exposed:              True
exposed-modules:      Database.Persist.Sql.Raw.QQ
hidden-modules:       Paths_persistent_qq
import-dirs:          /usr/lib/ghc-9.6.6/site-local/persistent-qq-2.12.0.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/persistent-qq-2.12.0.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/persistent-qq-2.12.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-qq
hs-libraries:         HSpersistent-qq-2.12.0.7-Bh5xC0O2VSz1FVQ3mqafvh
depends:
    base-4.18.2.1 haskell-src-meta-0.8.15-5WA14dofYHdB0COx7SkwL2
    mtl-2.3.1 persistent-2.14.5.2-9eq8y6ZCNqR84OxLjl0e2k
    template-haskell-2.20.0.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-persistent-qq/html/persistent-qq.haddock

haddock-html:         /usr/share/doc/haskell-persistent-qq/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
